<?php
namespace WTM\TeamManager;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
class Helper {

public static function get_team_picture($post_id, $thumb_image_size,$class=""){

        $thumbnail_id = get_post_thumbnail_id( $post_id );

        if (isset($thumbnail_id)) {

            return wp_get_attachment_image($thumbnail_id,$thumb_image_size, "", array( "class" => $class ));

        }

    }

public static function get_team_social_links($post_id)
{

    $output = '';
    $social_size = ( false !== get_option('tm_social_size') ) ? get_option('tm_social_size') : 16;
    $link_window = ( false !== get_option('tm_link_new_window')  && 'True' == get_option('tm_link_new_window') ) ? 'target="_blank"' : '';

    $facebook = get_post_meta($post_id,'tm_flink',true);
    $twitter = get_post_meta($post_id,'tm_tlink',true);
    $linkedIn = get_post_meta($post_id,'tm_llink',true);
    $googleplus = get_post_meta($post_id,'tm_gplink',true);
    $dribbble = get_post_meta($post_id,'tm_dribbble',true);
    $youtube = get_post_meta($post_id,'tm_ylink',true);
    $vimeo = get_post_meta($post_id,'tm_vlink',true);
    $emailid = get_post_meta($post_id,'tm_emailid',true);


    $output .= '<div class="team-member-socials size-'.esc_attr($social_size).'">';

    if (!empty($facebook)) {
    $output .= '<a class="facebook-'.esc_attr($social_size).'" href="' .esc_url($facebook) . '" '.esc_attr($link_window).' title="'.__('Facebook','wp-team-manager').'"><i class="fab fa-facebook-f"></i></a>';
    }
    if (!empty($twitter)) {
    $output .= '<a class="twitter-'.esc_attr($social_size).'" href="' . esc_url($twitter). '" '.esc_attr($link_window).' title="'.__('Twitter','wp-team-manager').'"><i class="fab fa-twitter"></i></a>';
    }
    if (!empty($linkedIn)) {
    $output .= '<a class="linkedIn-'.esc_attr($social_size).'" href="' . esc_url($linkedIn). '" '.esc_attr($link_window).' title="'.__('LinkedIn','wp-team-manager').'"><i class="fab fa-linkedin"></i></a>';
    }
    if (!empty($googleplus)) {
    $output .= '<a class="googleplus-'.esc_attr($social_size).'" href="' . esc_url($googleplus). '" '.esc_attr($link_window).' title="'.__('Google Plus','wp-team-manager').'"><i class="fab fa-google-plus-g"></i></a>';
    }
    if (!empty($dribbble)) {
    $output .= '<a class="dribbble-'.esc_attr($social_size).'" href="' . esc_url($dribbble). '" '.esc_attr($link_window).' title="'.__('Dribbble','wp-team-manager').'"><i class="fab fa-dribbble-square"></i></a>';
    }        
    if (!empty($youtube)) {
    $output .= '<a class="youtube-'.esc_attr($social_size).'" href="' . esc_url($youtube). '" '.esc_attr($link_window).' title="'.__('Youtube','wp-team-manager').'"><i class="fab fa-youtube"></i></a>';
    }
    if (!empty($vimeo)) {
    $output .= '<a class="vimeo-'.esc_attr($social_size).'" href="' . esc_url($vimeo). '" '.esc_attr($link_window).' title="'.__('Vimeo','wp-team-manager').'"><i class="fab fa-vimeo"></i></a>';
    }
    if (!empty($emailid)) {
    $output .= '<a class="emailid-'.esc_attr($social_size).'" href="mailto:' .sanitize_email($emailid). '" title="'.__('Email','wp-team-manager').'"><i class="far fa-envelope"></i></a>';
    } 

    $output .= '</div>';

    return $output;

}

public static function get_team_other_infos($post_id)
{
    
    $output = '';

    $tm_mobile = get_post_meta($post_id,'tm_mobile',true);
    $tm_year_experience = get_post_meta($post_id,'tm_year_experience',true);
    $tm_email = get_post_meta($post_id,'tm_email',true);
    $telephone = get_post_meta($post_id,'tm_telephone',true);
    $location = get_post_meta($post_id,'tm_location',true);
    $web_url = get_post_meta($post_id,'tm_web_url',true);
    $vcard = get_post_meta($post_id,'tm_vcard',true);

    $output .= '<div class="team-member-other-info">';

    if (!empty($tm_mobile)) {
        $output .= '<div class="team-member-info"><i class="fas fa-mobile-alt"></i></i> <a href="tel://'.esc_html($tm_mobile).'">'.esc_html($tm_mobile).'</a></div>';
    }
    if (!empty($telephone)) {
        $output .= '<div class="team-member-info"><i class="fas fa-phone-alt"></i> <a href="tel://'.esc_html($telephone).'">'.esc_html($telephone).'</a></div>';
    }
    if (!empty($tm_year_experience)) {
        $output .= '<div class="team-member-info"><i class="fas fa-history"></i>'.esc_html($tm_year_experience).'</div>';
    }
    if (!empty($location)) {
        $output .= '<div class="team-member-info"><i class="fas fa-map-marker"></i> '.esc_html($location).'</div>';
    }
    if (!empty($tm_email)) {
        $output .= '<div class="team-member-info"><i class="fas fa-envelope"></i>'.esc_html($tm_email).'</div>';
    }
    if (!empty($web_url)) {
        $output .= '<div class="team-member-info"><i class="fas fa-link"></i> <a href="'. esc_url($web_url).'" target="_blank">'.__('Bio','wp-team-manager').'</a></div>';
    }
    if (!empty($vcard)) {
        $output .= '<div class="team-member-info"><i class="fas fa-download"></i> <a href="'.esc_url($vcard).'" > '.__('Download VC','wp-team-manager').'</a></div>';
    }   
                                                
    $output .= '</div>';

    return $output;

}

    /**
	 * Get Post Pagination, Load more & Scroll markup
	 *
	 * @param $query
	 * @param $data
	 *
	 * @return false|string|void
	 */
	public static function get_pagination_markup( $query, $posts_per_page ) {

        $big = 999999999; // need an unlikely integer

		if ( $query->max_num_pages > 0 ) {
			$html = "<div class='dynamicpg-pagination-wrap' data-total-pages='{$query->max_num_pages}' data-posts-per-page='{$posts_per_page}' data-type='pagination' >";   
            $html .= paginate_links( array(
                'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
                'format' => '?paged=%#%',
                'current' => max( 1, get_query_var('paged') ),
                'total' => $query->max_num_pages
            ) );
            $html .= "</div>";
			return $html;
		}

		return false;
	}

    public static function get_wysiwyg_output( $meta_key, $post_id = 0 ) {
        global $wp_embed;
    
        $post_id = $post_id ? $post_id : get_the_id();
    
        $content = get_post_meta( $post_id, $meta_key, 1 );
        
        if($content){
            $content = $wp_embed->autoembed( $content );
            $content = $wp_embed->run_shortcode( $content );
            $content = wpautop( $content );
            $content = do_shortcode( $content );
        }
 
    
        return $content;
    }

}