<?php
use WTM\TeamManager\Helper;
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://http://www.dynamicweblab.com/
 * @since      1.0.0
 *
 * @package    Wp_Team_Manager
 * @subpackage Wp_Team_Manager/public
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Team manager Shortcode generator class
 */
class Wp_Team_Manager_Shortcode{

  public function __construct() {

    add_shortcode( 'team_manager', [$this, 'shortcode_callback'] );

  }

/**
 * Team manager Shortcode
 */
  public function shortcode_callback ($atts) {

    ob_start();
    
      $social_size = ( false !== get_option('tm_social_size') ) ? get_option('tm_social_size') : 16;
      $link_window = ( false !== get_option('tm_link_new_window')  && 'True' == get_option('tm_link_new_window') ) ? 'target="_blank"' : '';
      $disable_single_template = ( false !== get_option('single_team_member_view')  && 'True' == get_option('single_team_member_view') ) ? true : false;

      $shortcode_id = 'dwl-team-wrapper-'.uniqid();
  
      $settings = shortcode_atts( array(
        'orderby' => 'menu_order',
        'layout' => 'grid',
        'posts_per_page' => '-1',
        'post__in' => [],
        'post__not_in' => [],
        'show_other_info' => 'yes',
        'show_social' => 'yes',
        'image_style' => 'boxed',
        'image_size' => 'thumbnail',
        'category' => '0',
        'large_column' => '6',
        'tablet_column' => '6',
        'mobile_column' => '12',
        'bg_color' => '#fff',
        'social_color' => '#4258d6'
      ), $atts );

      $asc_desc = 'DESC';
  
      if ( isset($settings['orderby']) AND ($settings['orderby'] == 'title' || $settings['orderby'] == 'menu_order' )) {
        $asc_desc = 'ASC';
      }
  
      $posts_per_page = ( isset( $atts['posts_per_page'] ) AND absint($atts['posts_per_page']) >= 1 ) ? $atts['posts_per_page'] : -1 ;
      $layout = isset( $settings['layout'] ) ? $settings['layout'] : 'grid';
      $image_size = isset( $settings['image_size'] ) ? $settings['image_size'] : 'thumbnail';   
      $_paged        = is_front_page() ? "page" : "paged";
      $wrapper_calss = '';

      if( $layout != 'slider' ){
        $wrapper_calss = 'wtm-row g-2 g-lg-3';
      }

      $args = array( 
        'post_type' => 'team_manager',
        'post_status' => 'publish',
        'posts_per_page'=> $posts_per_page,
        'paged' => get_query_var( $_paged ) ? absint( get_query_var( $_paged ) ) : 1,
        'orderby' => isset( $settings['orderby'] ) ? $settings['orderby'] : '', 
        'order' => $asc_desc
      ); 

      if(isset( $settings['category'] ) AND '0' != $settings['category']){
        $args['tax_query'] = array(
            array(
            'taxonomy' => 'team_groups',
            'field' => 'slug',
            'terms' => $settings['category'],
            )
          );
      }
  
      if( isset( $settings['exclude'] ) AND $settings['exclude'] != '0' AND $settings['exclude'] != '' ) {
        $postnotarray = explode(',', $settings['exclude']);
        if( isset($postnotarray) AND is_array( $postnotarray ) && $postnotarray[0] !='' ) { 
          $args['post__not_in'] = $postnotarray;
        }
      }
  
      if( isset( $settings['post__in'] ) AND $settings['post__in'] != '0' AND $settings['post__in'] != '' ) {

        $postarray = explode( ',', $settings['post__in'] );

        if( isset($postarray) AND is_array( $postarray ) && $postarray[0] != '' ) { 
          $args['post__in'] = $postarray;
        }

      }    
      wp_enqueue_style([
        'wp-team-font-awesome',
        'wp-team-style'
      ]);

      if( 'slider' == $layout ){
        wp_enqueue_style([
          'wp-team-slick',
          'wp-team-slick-theme'
        ]);
        wp_enqueue_script([
          'wp-team-slick',
          'wp-team-script'
         ]);
      }

      $tm_loop = new \WP_Query( $args );      
  
      if ( $tm_loop->have_posts() ) :
        ?>
      <style>
        <?php if(!empty($settings['social_color'])): ?>
      #<?php echo esc_attr( $shortcode_id ); ?> .team-member-socials a{
        background-color: <?php echo esc_attr($settings['social_color']); ?>
        }
        #<?php echo esc_attr( $shortcode_id ); ?> .team-member-other-info .fas{
          color: <?php echo esc_attr($settings['social_color']); ?>
        }
        <?php endif; ?>
        <?php if(!empty($settings['bg_color'])): ?>
        #<?php echo esc_attr( $shortcode_id ); ?> .team-member-info-content{
          background-color: <?php echo esc_attr($settings['bg_color']); ?>
        }
        <?php endif; ?>
        <?php if(!empty($social_size)): ?>
        #<?php echo esc_attr( $shortcode_id ); ?> .team-member-socials a,
        #<?php echo esc_attr( $shortcode_id ); ?> .team-member-other-info .fas{
          font-size: <?php echo esc_attr($social_size); ?>
        }
        <?php endif; ?>
      </style>
      <div id="<?php echo esc_attr( $shortcode_id ); ?>" class="dwl-team-list dwl-team-wrapper wtm-container-fluid">
        <div class="dwl-team-wrapper--main <?php echo esc_attr( $wrapper_calss ); ?> dwl-team-layout-<?php echo esc_attr( $layout ) ?> dwl-team-image-style-<?php echo esc_attr( $settings['image_style'] );?>">
          <?php 

              if( $layout == 'grid' ) {
                include plugin_dir_path( __FILE__ ) . 'templates/content-grid.php';
              }
              if( $layout == 'list' ) {
                include plugin_dir_path( __FILE__ ) . 'templates/content-list.php';
              }
              if( $layout == 'slider' ) {
                include plugin_dir_path( __FILE__ ) . 'templates/content-slider.php';
              }
          ?>
          </div>
        </div>
  
        <?php
      endif;

      wp_reset_postdata();
  
    return ob_get_clean();

  }
}
new Wp_Team_Manager_Shortcode();