<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the Public-specific stylesheet and JavaScript.
 *
 * @package    Wp_Team_Manager
 * @subpackage Wp_Team_Manager/Public
 * @author     Maidul <dynamicweblab@gmail.com>
 */
class Wp_Team_Manager_Public {

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( ) {
		add_action( 'wp_enqueue_scripts', [ $this, 'wp_team_manager_public_assets' ] );
		add_action( 'wp_head', [ $this, 'team_manager_add_custom_css'] );
	}

	/**
	 * Register the stylesheets and script for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function wp_team_manager_public_assets() {
		wp_register_style( 'wp-team-font-awesome', TM_PUBLIC . '/assets/vendor/font-awesome/css/all.min.css', null, '5.9.0');
		wp_register_style( 'wp-team-slick', TM_PUBLIC . '/assets/vendor/slick/slick.css', null, '5.9.0');
		wp_register_style( 'wp-team-slick-theme', TM_PUBLIC . '/assets/vendor/slick/slick-theme.css', null, '5.9.0');
		wp_register_style( 'wp-team-single', TM_PUBLIC . '/assets/css/tm-single.css', [], TM_VERSION );
		wp_register_style( 'wp-team-style', TM_PUBLIC . '/assets/css/tm-style.css', [], TM_VERSION );

		// register scritps
		wp_register_script( 'wp-team-slick', TM_PUBLIC . '/assets/vendor/slick/slick.min.js', array('jquery'), '5.9.0', true );
		wp_register_script( 'wp-team-script', TM_PUBLIC . '/assets/js/team.js', array('jquery'), time(), true );
	
	}
    /**
     * Add custom css on theme header
     *
     * @since 1.0
     */
    public function team_manager_add_custom_css(){
		if(is_singular( 'team_manager' )){
			wp_enqueue_style(['wp-team-font-awesome','wp-team-single','wp-team-style']);
		}
		
        printf( "<style type='text/css' media='screen'>%s</style>", get_option('tm_custom_css') );
    } 
}

new Wp_Team_Manager_Public();
